@@ -122,7 +122,6 @@ data = {
         "HFE347mcc3": 575.0,
         "HFE347pcf2": 580.0,
         "HFE356pcc3": 110.0,
-        "HFE449s1": 297.0,
         "HFE569sf2": 59.0,
         "HFE4310pccc124": 1870.0,
         "HFE236ca12": 2800.0,
@@ -197,7 +196,6 @@ data = {
         "HFE347mcc3": 530.0,
         "HFE347pcf2": 889.0,
         "HFE356pcc3": 413.0,
-        "HFE449s1": 421.0,
         "HFE569sf2": 57.0,
         "HFE4310pccc124": 2820.0,
         "HFE236ca12": 5350.0,
@@ -213,7 +211,6 @@ data = {
         "HFE356mec3": 387.0,
         "HFE356pcf2": 719.0,
         "HFE356pcf3": 446.0,
-        "HFE365mcf3": 1.0,
         "HFE374pc2": 627.0,
         "PFPMIE": 9710.0,
         "CHCl3": 16.0,
@@ -288,7 +285,6 @@ data = {
         "HFE347mcc3": 641,
         "HFE347pcf2": 1072,
         "HFE356pcc3": 500,
-        "HFE449s1": 509,
         "HFE569sf2": 69,
         "HFE4310pccc124": 3353,
         "HFE236ca12": 6260,
@@ -315,8 +311,8 @@ data = {
     "AR6GWP100": {
         "CH4": 27.9,
         "N2O": 273.0,
-        "CFC11": 5560.0,
-        "CFC12": 11200.0,
+        "CFC11": 6230.0,
+        "CFC12": 12500.0,
         "CFC13": 16200.0,
         "CFC113": 6520.0,
         "CFC114": 9430.0,
@@ -378,7 +374,6 @@ data = {
         "HFE347mcc3": 576.0,
         "HFE347pcf2": 980.0,
         "HFE356pcc3": 277.0,
-        "HFE449s1": 460.0,
         "HFE569sf2": 60.7,
         "HFE4310pccc124": 3220.0,
         "HFE236ca12": 6060.0,
@@ -404,8 +399,8 @@ data = {
     "AR6GWP20": {
         "CH4": 81.2,
         "N2O": 273.0,
-        "CFC11": 7430.0,
-        "CFC12": 11400.0,
+        "CFC11": 8320.0,
+        "CFC12": 12700.0,
         "CFC13": 12400.0,
         "CFC113": 6860.0,
         "CFC114": 8260.0,
@@ -467,7 +462,6 @@ data = {
         "HFE347mcc3": 2020.0,
         "HFE347pcf2": 3370.0,
         "HFE356pcc3": 995.0,
-        "HFE449s1": 1620.0,
         "HFE569sf2": 219.0,
         "HFE4310pccc124": 8720.0,
         "HFE236ca12": 11700.0,
@@ -490,4 +484,180 @@ data = {
         "CH3Cl": 19.9,
         "Halon1201": 1340.0,
     },
+    "AR6GWP500": {
+        "CH4": 7.95,
+        "N2O": 130.0,
+        "CFC11": 2090.0,
+        "CFC12": 5710.0,
+        "CFC13": 17500.0,
+        "CFC113": 2830.0,
+        "CFC114": 6150.0,
+        "CFC115": 9880.0,
+        "Halon1301": 2750.0,
+        "Halon1211": 552.0,
+        "Halon2402": 639.0,
+        "Halon1202": 61.5,
+        "CCl4": 658.0,
+        "CH3Br": 0.692,
+        "CH3CCl3": 46.0,
+        "HCFC21": 45.6,
+        "HCFC22": 560.0,
+        "HCFC123": 25.8,
+        "HCFC124": 170.0,
+        "HCFC141b": 246.0,
+        "HCFC142b": 658.0,
+        "HCFC225ca": 39.0,
+        "HCFC225cb": 162.0,
+        "HFC23": 10500.0,
+        "HFC32": 220.0,
+        "HFC41": 38.6,
+        "HFC125": 1110.0,
+        "HFC134": 361.0,
+        "HFC134a": 436.0,
+        "HFC143": 104.0,
+        "HFC143a": 1940.0,
+        "HFC152": 6.14,
+        "HFC152a": 46.8,
+        "HFC161": 1.38,
+        "HFC227ea": 1100.0,
+        "HFC236cb": 387.0,
+        "HFC236ea": 428.0,
+        "HFC236fa": 6040.0,
+        "HFC245ca": 225.0,
+        "HFC245fa": 274.0,
+        "HFC365mfc": 261.0,
+        "HFC4310mee": 458.0,
+        "SO2F2": 1410.0,
+        "SF6": 34100.0,
+        "NF3": 18200.0,
+        "CF4": 10600.0,
+        "C2F6": 17500.0,
+        "C3F8": 12400.0,
+        "cC4F8": 13800.0,
+        "C4F10": 13400.0,
+        "C5F12": 12700.0,
+        "C6F14": 11600.0,
+        "C7F16": 11300.0,
+        "C8F18": 11100.0,
+        "C10F18": 9780.0,
+        "SF5CF3": 21100.0,
+        "HFE125": 7680.0,
+        "HFE134": 1940.0,
+        "HFE143a": 176.0,
+        "HCFE235da2": 154.0,
+        "HFE245cb2": 213.0,
+        "HFE245fa2": 251.0,
+        "HFE347mcc3": 164.0,
+        "HFE347pcf2": 279.0,
+        "HFE356pcc3": 79.0,
+        "HFE569sf2": 17.3,
+        "HFE4310pccc124": 920.0,
+        "HFE236ca12": 1770.0,
+        "HFE338pcc13": 948.0,
+        "HFE227ea": 2570.0,
+        "HFE236ea2": 741.0,
+        "HFE236fa": 315.0,
+        "HFE245fa1": 266.0,
+        "HFE329mcc2": 1100.0,
+        "HFE338mcf2": 297.0,
+        "HFE347mcf2": 275.0,
+        "HFE356mec3": 75.3,
+        "HFE356pcf2": 237.0,
+        "HFE356pcf3": 138.0,
+        "HFE365mcf3": 0.457,
+        "HFE374pc2": 3.56,
+        "PFPMIE": 11700.0,
+        "CHCl3": 5.87,
+        "CH2Cl2": 3.18,
+        "CH3Cl": 1.58,
+        "Halon1201": 108.0,
+    },
+    "AR6GTP100": {
+        "CH4": 5.38,
+        "N2O": 233.0,
+        "CFC11": 3540.0,
+        "CFC12": 10400.0,
+        "CFC13": 18800.0,
+        "CFC113": 5210.0,
+        "CFC114": 9410.0,
+        "CFC115": 11000.0,
+        "Halon1301": 5060.0,
+        "Halon1211": 406.0,
+        "Halon2402": 702.0,
+        "Halon1202": 39.3,
+        "CCl4": 810.0,
+        "CH3Br": 0.438,
+        "CH3CCl3": 29.7,
+        "HCFC21": 29.0,
+        "HCFC22": 379.0,
+        "HCFC123": 16.4,
+        "HCFC124": 110.0,
+        "HCFC141b": 162.0,
+        "HCFC142b": 514.0,
+        "HCFC225ca": 24.8,
+        "HCFC225cb": 105.0,
+        "HFC23": 15100.0,
+        "HFC32": 142.0,
+        "HFC41": 24.6,
+        "HFC125": 1300.0,
+        "HFC134": 239.0,
+        "HFC134a": 306.0,
+        "HFC143": 66.6,
+        "HFC143a": 3250.0,
+        "HFC152": 3.89,
+        "HFC152a": 29.8,
+        "HFC161": 0.872,
+        "HFC227ea": 1490.0,
+        "HFC236cb": 268.0,
+        "HFC236ea": 288.0,
+        "HFC236fa": 8870.0,
+        "HFC245ca": 146.0,
+        "HFC245fa": 180.0,
+        "HFC365mfc": 172.0,
+        "HFC4310mee": 347.0,
+        "SO2F2": 1920.0,
+        "SF6": 30600.0,
+        "NF3": 20000.0,
+        "CF4": 9050.0,
+        "C2F6": 15200.0,
+        "C3F8": 11200.0,
+        "cC4F8": 12400.0,
+        "C4F10": 12100.0,
+        "C5F12": 11200.0,
+        "C6F14": 10500.0,
+        "C7F16": 10200.0,
+        "C8F18": 10000.0,
+        "C10F18": 9010.0,
+        "SF5CF3": 21600.0,
+        "HFE125": 13100.0,
+        "HFE134": 2060.0,
+        "HFE143a": 113.0,
+        "HCFE235da2": 98.4,
+        "HFE245cb2": 137.0,
+        "HFE245fa2": 162.0,
+        "HFE347mcc3": 106.0,
+        "HFE347pcf2": 181.0,
+        "HFE356pcc3": 50.4,
+        "HFE569sf2": 11.0,
+        "HFE4310pccc124": 647.0,
+        "HFE236ca12": 1860.0,
+        "HFE338pcc13": 657.0,
+        "HFE227ea": 4440.0,
+        "HFE236ea2": 521.0,
+        "HFE236fa": 205.0,
+        "HFE245fa1": 173.0,
+        "HFE329mcc2": 1090.0,
+        "HFE338mcf2": 194.0,
+        "HFE347mcf2": 179.0,
+        "HFE356mec3": 48.0,
+        "HFE356pcf2": 154.0,
+        "HFE356pcf3": 88.4,
+        "HFE365mcf3": 0.289,
+        "HFE374pc2": 2.25,
+        "PFPMIE": 12000.0,
+        "CHCl3": 3.72,
+        "CH2Cl2": 2.01,
+        "CH3Cl": 1.0,
+        "Halon1201": 69.8,
+    },
 }
